@@ -1,10 +1,10 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "adoc-mode" "0.7.0"
+(define-package "adoc-mode" "0.8.0"
   "A major-mode for editing AsciiDoc files."
-  '((emacs "26"))
+  '((emacs "28.1"))
   :url "https://github.com/bbatsov/adoc-mode"
-  :commit "66b9adc97d8702de47140092cbae3a2f5563a297"
-  :revdesc "66b9adc97d87"
-  :keywords '("docs" "wp")
+  :commit "6fc5ebc9478de17b1971222485e7729f04fbcf57"
+  :revdesc "6fc5ebc9478d"
+  :keywords '("asciidoc" "text")
   :authors '(("Florian Kaufmann" . "sensorflo@gmail.com"))
   :maintainers '(("Bozhidar Batsov" . "bozhidar@batsov.dev")))
